@@ -124,15 +124,15 @@ void DeclarationBuilder::closeDeclaration()
     DeclarationBuilderBase::closeDeclaration();
 }
 
-template<typename T> T* DeclarationBuilder::eventuallyReopenDeclaration(Identifier* name, Ast* range, FitDeclarationType mustFitType)
+template<typename T> T* DeclarationBuilder::eventuallyReopenDeclaration(Identifier* name, FitDeclarationType mustFitType)
 {
     QList<Declaration*> existingDeclarations = existingDeclarationsForNode(name);
-    
-    Declaration* dec = 0;
-    reopenFittingDeclaration<T>(existingDeclarations, mustFitType, editorFindRange(range, range), &dec);
+
+    Declaration* dec = nullptr;
+    reopenFittingDeclaration<T>(existingDeclarations, mustFitType, editorFindRange(name, name), &dec);
     bool declarationOpened = (bool) dec;
     if ( ! declarationOpened ) {
-        dec = openDeclaration<T>(name, range);
+        dec = openDeclaration<T>(name);
     }
     Q_ASSERT(dynamic_cast<T*>(dec));
     return static_cast<T*>(dec);
@@ -148,24 +148,23 @@ template<typename T> T* DeclarationBuilder::visitVariableDeclaration(Ast* node,
         // This is just a sanity check, the code should never request creation of a variable
         // in such cases.
         if ( currentVariableDefinition->context != ExpressionAst::Context::Store ) {
-            return 0;
+            return nullptr;
         }
-        Identifier* id = currentVariableDefinition->identifier;
-        return visitVariableDeclaration<T>(id, currentVariableDefinition, previous, type, flags);
+        return visitVariableDeclaration<T>(currentVariableDefinition->identifier, previous, type, flags);
     }
     else if ( node->astType == Ast::IdentifierAstType ) {
-        return visitVariableDeclaration<T>(static_cast<Identifier*>(node), nullptr, previous, type, flags);
+        return visitVariableDeclaration<T>(static_cast<Identifier*>(node), previous, type, flags);
     }
     else {
         qCWarning(KDEV_PYTHON_DUCHAIN) << "cannot create variable declaration for non-(name|identifier) AST, this is a programming error";
-        return static_cast<T*>(0);
+        return static_cast<T*>(nullptr);
     }
 }
 
 QList< Declaration* > DeclarationBuilder::existingDeclarationsForNode(Identifier* node)
 {
     return currentContext()->findDeclarations(
-        identifierForNode(node).last(), CursorInRevision::invalid(), 0,
+        identifierForNode(node).last(), CursorInRevision::invalid(), nullptr,
         (DUContext::SearchFlag) (DUContext::DontSearchInParent | DUContext::DontResolveAliases)
     );
 }
@@ -189,7 +188,7 @@ template<typename T> QList<Declaration*> DeclarationBuilder::reopenFittingDeclar
 {
     // Search for a declaration from a previous parse pass which should be re-used
     QList<Declaration*> remainingDeclarations;
-    *ok = 0;
+    *ok = nullptr;
     foreach ( Declaration* d, declarations ) {
         Declaration* fitting = dynamic_cast<T*>(d);
         if ( ! fitting ) {
@@ -205,7 +204,7 @@ template<typename T> QList<Declaration*> DeclarationBuilder::reopenFittingDeclar
         if ( d->abstractType() && mustFitType != NoTypeRequired ) {
             invalidType = ( ( d->isFunctionDeclaration() ) != ( mustFitType == FunctionDeclarationType ) );
             if ( ! invalidType ) {
-                invalidType = ( ( dynamic_cast<AliasDeclaration*>(d) != 0 ) != ( mustFitType == AliasDeclarationType ) );
+                invalidType = ( ( dynamic_cast<AliasDeclaration*>(d) != nullptr ) != ( mustFitType == AliasDeclarationType ) );
             }
         }
         if ( fitting && ! reallyEncountered && ! invalidType ) {
@@ -227,13 +226,11 @@ template<typename T> QList<Declaration*> DeclarationBuilder::reopenFittingDeclar
     return remainingDeclarations;
 }
 
-template<typename T> T* DeclarationBuilder::visitVariableDeclaration(Identifier* node, Ast* originalAst, Declaration* previous,
+template<typename T> T* DeclarationBuilder::visitVariableDeclaration(Identifier* node, Declaration* previous,
                                                                      AbstractType::Ptr type, VisitVariableFlags flags)
 {
     DUChainWriteLocker lock;
-    Ast* rangeNode = originalAst ? originalAst : node;
-    RangeInRevision range = editorFindRange(rangeNode, rangeNode);
-    
+    RangeInRevision range = editorFindRange(node, node);
     // ask the correction file library if there's a user-specified type for this object
     if ( AbstractType::Ptr hint = m_correctionHelper->hintForLocal(node->value) ) {
         type = hint;
@@ -254,7 +251,7 @@ template<typename T> T* DeclarationBuilder::visitVariableDeclaration(Identifier*
     }
     
     // declaration existing in a previous version of this top-context
-    Declaration* dec = 0;
+    Declaration* dec = nullptr;
     existingDeclarations = reopenFittingDeclaration<T>(existingDeclarations, kindForType(type), range, &dec);
     bool declarationOpened = (bool) dec;
     if ( flags & AbortIfReopenMismatch && previous && ! declarationOpened ) {
@@ -279,7 +276,7 @@ template<typename T> T* DeclarationBuilder::visitVariableDeclaration(Identifier*
     if ( currentContext() && currentContext()->type() == DUContext::Class && ! haveFittingDeclaration ) {
         // If the current context is a class, then this is a class member variable.
         if ( ! dec ) {
-            dec = openDeclaration<ClassMemberDeclaration>(identifierForNode(node), range);
+            dec = openDeclaration<ClassMemberDeclaration>(node);
             Q_ASSERT(! declarationOpened);
             declarationOpened = true;
         }
@@ -292,7 +289,7 @@ template<typename T> T* DeclarationBuilder::visitVariableDeclaration(Identifier*
         // This name did not previously appear in the user code, so a new variable is declared
         // check whether a declaration from a previous parser pass must be updated
         if ( ! dec ) {
-            dec = openDeclaration<T>(identifierForNode(node), range);
+            dec = openDeclaration<T>(node);
             Q_ASSERT(! declarationOpened);
             declarationOpened = true;
         }
@@ -354,7 +351,7 @@ void DeclarationBuilder::visitExceptionHandler(ExceptionHandlerAst* node)
         // Python allows to assign the caught exception to a variable; create that variable if required.
         ExpressionVisitor v(currentContext());
         v.visitNode(node->type);
-        visitVariableDeclaration<Declaration>(node->name, 0, v.lastType());
+        visitVariableDeclaration<Declaration>(node->name, nullptr, v.lastType());
     }
     DeclarationBuilderBase::visitExceptionHandler(node);
 }
@@ -365,7 +362,7 @@ void DeclarationBuilder::visitWithItem(WithItemAst* node)
         // For statements like "with open(f) as x", a new variable must be created; do this here.
         ExpressionVisitor v(currentContext());
         v.visitNode(node->contextExpression);
-        visitVariableDeclaration<Declaration>(node->optionalVars, 0, v.lastType());
+        visitVariableDeclaration<Declaration>(node->optionalVars, nullptr, v.lastType());
     }
     Python::AstDefaultVisitor::visitWithItem(node);
 }
@@ -385,19 +382,19 @@ Declaration* DeclarationBuilder::findDeclarationInContext(QStringList dottedName
     DUChainReadLocker lock(DUChain::lock());
     DUContext* currentContext = ctx;
     // TODO make this a bit faster, it wastes time
-    Declaration* lastAccessedDeclaration = 0;
+    Declaration* lastAccessedDeclaration = nullptr;
     int i = 0;
     int identifierCount = dottedNameIdentifier.length();
     foreach ( const QString& currentIdentifier, dottedNameIdentifier ) {
         Q_ASSERT(currentContext);
         i++;
         QList<Declaration*> declarations = currentContext->findDeclarations(QualifiedIdentifier(currentIdentifier).first(),
-                                                                            CursorInRevision::invalid(), 0, DUContext::NoFiltering);
+                                                                            CursorInRevision::invalid(), nullptr, DUContext::NoFiltering);
         // break if the list of identifiers is not yet totally worked through and no
         // declaration with an internal context was found
         if ( declarations.isEmpty() || ( !declarations.last()->internalContext() && identifierCount != i ) ) {
             qCDebug(KDEV_PYTHON_DUCHAIN) << "Declaration not found: " << dottedNameIdentifier << "in top context" << ctx->url().toUrl().path();
-            return 0;
+            return nullptr;
         }
         else {
             lastAccessedDeclaration = declarations.last();
@@ -429,7 +426,7 @@ void DeclarationBuilder::visitImportFrom(ImportFromAst* node)
     QString declarationName;
     foreach ( AliasAst* name, node->names ) {
         // iterate over all the names that are imported, like "from foo import bar as baz, bang as asdf"
-        Identifier* declarationIdentifier = 0;
+        Identifier* declarationIdentifier = nullptr;
         declarationName.clear();
         if ( name->asName ) {
             // use either the alias ("as foo"), or the object name itself if no "as" is given
@@ -443,12 +440,12 @@ void DeclarationBuilder::visitImportFrom(ImportFromAst* node)
         // This is a bit hackish, it tries to find the specified object twice twice -- once it tries to
         // import the name from a module's __init__.py file, and once from a "real" python file
         // TODO improve this code-wise
-        ProblemPointer problem(0);
+        ProblemPointer problem(nullptr);
         QString intermediate;
         moduleName = buildModuleNameFromNode(node, name, intermediate);
         Declaration* success = createModuleImportDeclaration(moduleName, declarationName, declarationIdentifier, problem);
         if ( ! success && (node->module || node->level) ) {
-            ProblemPointer problem_init(0);
+            ProblemPointer problem_init(nullptr);
             intermediate = QString("__init__");
             moduleName = buildModuleNameFromNode(node, name, intermediate);
             success = createModuleImportDeclaration(moduleName, declarationName, declarationIdentifier, problem_init);
@@ -460,29 +457,9 @@ void DeclarationBuilder::visitImportFrom(ImportFromAst* node)
     }
 }
 
-void spoofNodePosition(Ast* node, const CursorInRevision& pos) {
-    // Ridiculous hack, see next comment.
-    node->startLine = node->endLine = pos.line;
-    node->startCol = node->endCol = pos.column - 1;
-    if (node->astType == Ast::TupleAstType) {
-        //  Recursion to bodge all declarations, e.g.
-        //  [x + y * z for x, (y, z) in foo]
-        foreach(auto elem, static_cast<TupleAst*>(node)->elements) {
-            spoofNodePosition(elem, pos);
-        }
-    }
-}
-
 void DeclarationBuilder::visitComprehension(ComprehensionAst* node)
 {
     Python::AstDefaultVisitor::visitComprehension(node);
-    // make the declaration zero chars long; it must appear at the beginning of the context,
-    // because it is actually used *before* its real declaration: [foo for foo in bar]
-    // The DUChain doesn't like this, so for now, the declaration is at the opening bracket,
-    // and both other occurrences are uses of that declaration.
-    // TODO add a special case to the usebuilder to display the second occurrence as a declaration
-    spoofNodePosition(node->target, currentContext()->range().start);
-
     ExpressionVisitor v(currentContext());
     v.visitNode(node->iterator);
     assignToUnknown(node->target, Helper::contentOfIterable(v.lastType(), topContext()));
@@ -496,7 +473,7 @@ void DeclarationBuilder::visitImport(ImportAst* node)
         QString moduleName = name->name->value;
         // use alias if available, name otherwise
         Identifier* declarationIdentifier = name->asName ? name->asName : name->name;
-        ProblemPointer problem(0);
+        ProblemPointer problem(nullptr);
         createModuleImportDeclaration(moduleName, declarationIdentifier->value, declarationIdentifier, problem);
         if ( problem ) {
             DUChainWriteLocker lock;
@@ -532,7 +509,7 @@ Declaration* DeclarationBuilder::createDeclarationTree(const QStringList& nameCo
     
     qCDebug(KDEV_PYTHON_DUCHAIN) << "creating declaration tree for" << nameComponents;
     
-    Declaration* lastDeclaration = 0;
+    Declaration* lastDeclaration = nullptr;
     int depth = 0;
     
     // check for already existing trees to update
@@ -548,7 +525,7 @@ Declaration* DeclarationBuilder::createDeclarationTree(const QStringList& nameCo
         }
     }
     
-    DUContext* extendingPreviousImportCtx = 0;
+    DUContext* extendingPreviousImportCtx = nullptr;
     QStringList remainingNameComponents;
     bool injectingContext = false;
     if ( lastDeclaration && lastDeclaration->internalContext() ) {
@@ -578,7 +555,7 @@ Declaration* DeclarationBuilder::createDeclarationTree(const QStringList& nameCo
         // Iterate over all the names, and create a declaration + sub-context for each of them
         const QString& component = remainingNameComponents.at(i);
         Identifier temporaryIdentifier(component);
-        Declaration* d = 0;
+        Declaration* d = nullptr;
         temporaryIdentifier.copyRange(declarationIdentifier);
         temporaryIdentifier.endCol = temporaryIdentifier.startCol;
         temporaryIdentifier.startCol += 1;
@@ -593,7 +570,6 @@ Declaration* DeclarationBuilder::createDeclarationTree(const QStringList& nameCo
                ) {
                 aliasDeclaration = Helper::resolveAliasDeclaration(aliasDeclaration);
                 AliasDeclaration* adecl = eventuallyReopenDeclaration<AliasDeclaration>(&temporaryIdentifier,
-                                                                                        &temporaryIdentifier,
                                                                                         AliasDeclarationType);
                 if ( adecl ) {
                     adecl->setAliasedDeclaration(aliasDeclaration);
@@ -684,7 +660,7 @@ Declaration* DeclarationBuilder::createDeclarationTree(const QStringList& nameCo
         // return the lowest-level element in the tree, for the caller to do stuff with
         return openedDeclarations.last();
     }
-    else return 0;
+    else return nullptr;
 }
 
 Declaration* DeclarationBuilder::createModuleImportDeclaration(QString moduleName, QString declarationName,
@@ -708,7 +684,7 @@ Declaration* DeclarationBuilder::createModuleImportDeclaration(QString moduleNam
     const IndexedString modulePath = IndexedString(moduleInfo.first);
     ReferencedTopDUContext moduleContext = DUChain::self()->chainForDocument(modulePath);
     lock.unlock();
-    Declaration* resultingDeclaration = 0;
+    Declaration* resultingDeclaration = nullptr;
     if ( ! moduleInfo.first.isValid() ) {
         // The file was not found -- this is either an error in the user's code,
         // a missing module, or a C module (.so) which is unreadable for kdevelop
@@ -721,7 +697,7 @@ Declaration* DeclarationBuilder::createModuleImportDeclaration(QString moduleNam
         p->setDescription(i18n("Module \"%1\" not found", moduleName));
         m_missingModules.append(IndexedString(moduleName));
         problemEncountered = p;
-        return 0;
+        return nullptr;
     }
     if ( ! moduleContext ) {
         // schedule the include file for parsing, and schedule the current one for reparsing after that is done
@@ -730,12 +706,12 @@ Declaration* DeclarationBuilder::createModuleImportDeclaration(QString moduleNam
         Helper::scheduleDependency(modulePath, m_ownPriority);
         // parseDocuments() must *not* be called from a background thread!
         // KDevelop::ICore::self()->languageController()->backgroundParser()->parseDocuments();
-        return 0;
+        return nullptr;
     }
     if ( moduleInfo.second.isEmpty() ) {
         // import the whole module
         resultingDeclaration = createDeclarationTree(declarationName.split("."),
-                                                     declarationIdentifier, moduleContext, 0, range);
+                                                     declarationIdentifier, moduleContext, nullptr, range);
         auto initFile = QStringLiteral("/__init__.py");
         auto path = moduleInfo.first.path();
         if ( path.endsWith(initFile) ) {
@@ -759,7 +735,7 @@ Declaration* DeclarationBuilder::createModuleImportDeclaration(QString moduleNam
                     Identifier id = *declarationIdentifier;
                     id.value.append(".").append(filePath.last());
                     createDeclarationTree(filePath,
-                                          &id, fileContext, 0);
+                                          &id, fileContext, nullptr);
                 }
                 else {
                     m_unresolvedImports.append(IndexedString(fileUrl));
@@ -781,7 +757,7 @@ Declaration* DeclarationBuilder::createModuleImportDeclaration(QString moduleNam
             if ( originalDeclaration ) {
                 DUChainWriteLocker lock(DUChain::lock());
                 resultingDeclaration = createDeclarationTree(declarationName.split("."), declarationIdentifier,
-                                                             ReferencedTopDUContext(0), originalDeclaration,
+                                                             ReferencedTopDUContext(nullptr), originalDeclaration,
                                                              editorFindRange(declarationIdentifier, declarationIdentifier));
             }
             else {
@@ -840,7 +816,6 @@ void DeclarationBuilder::visitYield(YieldAst* node)
 
 void DeclarationBuilder::visitLambda(LambdaAst* node)
 {
-    Python::AstDefaultVisitor::visitLambda(node);
     DUChainWriteLocker lock;
     // A context must be opened, because the lamdba's arguments are local to the lambda:
     // d = lambda x: x*2; print x # <- gives an error
@@ -848,12 +823,14 @@ void DeclarationBuilder::visitLambda(LambdaAst* node)
     foreach ( ArgAst* argument, node->arguments->arguments ) {
         visitVariableDeclaration<Declaration>(argument->argumentName);
     }
+    visitNodeList(node->arguments->defaultValues);
     if (node->arguments->vararg) {
         visitVariableDeclaration<Declaration>(node->arguments->vararg->argumentName);
     }
     if (node->arguments->kwarg) {
         visitVariableDeclaration<Declaration>(node->arguments->kwarg->argumentName);
     }
+    visitNode(node->body);
     closeContext();
 }
 
@@ -868,7 +845,7 @@ void DeclarationBuilder::applyDocstringHints(CallAst* node, FunctionDeclaration:
         return;
     }
     // Don't do updates to pre-defined functions.
-    if ( ! v.lastDeclaration() || v.lastDeclaration()->topContext()->url() == IndexedString(Helper::getDocumentationFile()) ) {
+    if ( ! v.lastDeclaration() || v.lastDeclaration()->topContext()->url() == Helper::getDocumentationFile() ) {
         return;
     }
     // Check for the different types of modifiers such a function can have
@@ -898,20 +875,10 @@ void DeclarationBuilder::applyDocstringHints(CallAst* node, FunctionDeclaration:
         }
         ExpressionVisitor argVisitor(currentContext());
         argVisitor.visitNode(node->arguments.at(offset));
-        DUChainWriteLocker wlock;
-        if ( ! argVisitor.lastType() ) {
-            return;
-        }
-        auto sources = Helper::filterType<ListType>(
-            argVisitor.lastType(), [](AbstractType::Ptr type) {
-                return type.cast<ListType>();
-            }
-        );
-        for ( auto sourceContainer : sources ) {
-            if ( ! sourceContainer->contentType() ) {
-                continue;
-            }
-            container->addContentType<Python::UnsureType>(sourceContainer->contentType().abstractType());
+        if ( argVisitor.lastType() ) {
+            DUChainWriteLocker wlock;
+            auto contentType = Helper::contentOfIterable(argVisitor.lastType(), topContext());
+            container->addContentType<Python::UnsureType>(contentType);
             v.lastDeclaration()->setType(container);
         }
     };
@@ -934,7 +901,7 @@ void DeclarationBuilder::addArgumentTypeHints(CallAst* node, DeclarationPointer
     if ( ! function ) {
         return;
     }
-    if ( function->topContext()->url() == IndexedString(Helper::getDocumentationFile()) ) {
+    if ( function->topContext()->url() == Helper::getDocumentationFile() ) {
         return;
     }
     // Note: within this function:
@@ -1124,14 +1091,13 @@ void DeclarationBuilder::assignToName(NameAst* target, const DeclarationBuilder:
 {
     if ( element.isAlias ) {
         DUChainWriteLocker lock;
-        Python::Identifier* identifier = target->identifier;
-        AliasDeclaration* decl = eventuallyReopenDeclaration<AliasDeclaration>(identifier, target, AliasDeclarationType);
+        AliasDeclaration* decl = eventuallyReopenDeclaration<AliasDeclaration>(target->identifier, AliasDeclarationType);
         decl->setAliasedDeclaration(element.declaration.data());
         closeDeclaration();
     }
     else {
         DUChainWriteLocker lock;
-        Declaration* dec = visitVariableDeclaration<Declaration>(target, 0, element.type);
+        Declaration* dec = visitVariableDeclaration<Declaration>(target, nullptr, element.type);
         if ( dec && m_lastComment && ! m_lastComment->usedAsComment ) {
             dec->setComment(m_lastComment->value);
             m_lastComment->usedAsComment = true;
@@ -1182,7 +1148,7 @@ void DeclarationBuilder::assignToAttribute(AttributeAst* attrib, const Declarati
     checkPreviousAttributes.visitNode(attrib->value);
     DeclarationPointer parentObjectDeclaration = checkPreviousAttributes.lastDeclaration();
 
-    DUContextPointer internal(0);
+    DUContextPointer internal(nullptr);
 
     if ( ! parentObjectDeclaration ) {
         qCDebug(KDEV_PYTHON_DUCHAIN) << "No declaration for attribute base, aborting creation of attribute";
@@ -1221,7 +1187,7 @@ void DeclarationBuilder::assignToAttribute(AttributeAst* attrib, const Declarati
         if ( isAlreadyOpen ) {
             activateAlreadyOpenedContext(internal);
             visitVariableDeclaration<ClassMemberDeclaration>(
-                attrib->attribute, attrib, attributeDeclaration, element.type, AbortIfReopenMismatch
+                attrib->attribute, attributeDeclaration, element.type, AbortIfReopenMismatch
             );
             closeAlreadyOpenedContext(internal);
         }
@@ -1229,7 +1195,7 @@ void DeclarationBuilder::assignToAttribute(AttributeAst* attrib, const Declarati
             injectContext(internal.data());
 
             Declaration* dec = visitVariableDeclaration<ClassMemberDeclaration>(
-                attrib->attribute, attrib, attributeDeclaration, element.type, AbortIfReopenMismatch
+                attrib->attribute, attributeDeclaration, element.type, AbortIfReopenMismatch
             );
             if ( dec ) {
                 dec->setRange(RangeInRevision(internal->range().start, internal->range().start));
@@ -1375,12 +1341,13 @@ void DeclarationBuilder::visitAnnotationAssignment(AnnotationAssignmentAst* node
 void DeclarationBuilder::visitClassDefinition( ClassDefinitionAst* node )
 {
     visitNodeList(node->decorators);
+    visitNodeList(node->baseClasses);
     const CorrectionHelper::Recursion r(m_correctionHelper->enterClass(node->name->value));
 
     StructureType::Ptr type(new StructureType());
 
     DUChainWriteLocker lock;
-    ClassDeclaration* dec = eventuallyReopenDeclaration<ClassDeclaration>(node->name, node->name, NoTypeRequired);
+    ClassDeclaration* dec = eventuallyReopenDeclaration<ClassDeclaration>(node->name, NoTypeRequired);
     eventuallyAssignInternalContext();
 
     dec->setKind(KDevelop::Declaration::Type);
@@ -1454,9 +1421,7 @@ void DeclarationBuilder::visitClassDefinition( ClassDefinitionAst* node )
     dec->setInternalContext(currentContext());
 
     lock.unlock();
-    foreach ( Ast* _node, node->body ) {
-        AstDefaultVisitor::visitNode(_node);
-    }
+    visitNodeList(node->body);
     lock.lock();
 
     closeContext();
@@ -1475,7 +1440,7 @@ void DeclarationBuilder::visitFunctionDefinition( FunctionDefinitionAst* node )
     FunctionType::Ptr type(new FunctionType());
 
     DUChainWriteLocker lock;
-    FunctionDeclaration* dec = eventuallyReopenDeclaration<FunctionDeclaration>(node->name, node->name,
+    FunctionDeclaration* dec = eventuallyReopenDeclaration<FunctionDeclaration>(node->name,
                                                                                 FunctionDeclarationType);
 
     Q_ASSERT(dec->isFunctionDeclaration());
@@ -1778,7 +1743,7 @@ void DeclarationBuilder::visitArguments( ArgumentsAst* node )
         if ( currentIndex == 1 && workingOnDeclaration->isClassMethod() ) {
             DUChainWriteLocker lock;
             AliasDeclaration* decl = eventuallyReopenDeclaration<AliasDeclaration>(arg->argumentName,
-                                                                                   arg, AliasDeclarationType);
+                                                                                   AliasDeclarationType);
             if ( ! m_currentClassTypes.isEmpty() ) {
                 auto classDecl = m_currentClassTypes.last()->declaration(topContext());
 
@@ -1848,7 +1813,7 @@ void DeclarationBuilder::visitArguments( ArgumentsAst* node )
         IndexedContainer::Ptr tupleType = ExpressionVisitor::typeObjectForIntegralType<IndexedContainer>("tuple");
         lock.unlock();
         if ( tupleType ) {
-            visitVariableDeclaration<Declaration>(node->vararg->argumentName, 0, tupleType.cast<AbstractType>());
+            visitVariableDeclaration<Declaration>(node->vararg->argumentName, nullptr, tupleType.cast<AbstractType>());
             workingOnDeclaration->setVararg(atIndex);
             type->addArgument(tupleType.cast<AbstractType>(), useIndex);
         }
@@ -1861,7 +1826,7 @@ void DeclarationBuilder::visitArguments( ArgumentsAst* node )
         lock.unlock();
         if ( dictType && stringType ) {
             dictType->addKeyType<Python::UnsureType>(stringType);
-            visitVariableDeclaration<Declaration>(node->kwarg->argumentName, 0, dictType.cast<AbstractType>());
+            visitVariableDeclaration<Declaration>(node->kwarg->argumentName, nullptr, dictType.cast<AbstractType>());
             type->addArgument(dictType.cast<AbstractType>());
             workingOnDeclaration->setKwarg(type->arguments().size() - 1);
         }
@@ -1890,7 +1855,7 @@ void DeclarationBuilder::visitGlobal(GlobalAst* node)
         DUChainWriteLocker lock;
         QList< Declaration* > existing = top->findLocalDeclarations(qid.first());
         if ( ! existing.empty() ) {
-            AliasDeclaration* ndec = openDeclaration<AliasDeclaration>(id, node);
+            AliasDeclaration* ndec = openDeclaration<AliasDeclaration>(id);
             ndec->setAliasedDeclaration(existing.first());
             closeDeclaration();
         }
@@ -1900,7 +1865,7 @@ void DeclarationBuilder::visitGlobal(GlobalAst* node)
             dec->setRange(editorFindRange(id, id));
             dec->setAutoDeclaration(true);
             closeContext();
-            AliasDeclaration* ndec = openDeclaration<AliasDeclaration>(id, node);
+            AliasDeclaration* ndec = openDeclaration<AliasDeclaration>(id);
             ndec->setAliasedDeclaration(dec);
             closeDeclaration();
         }
